@@ -35,6 +35,7 @@ from logging import warning
 import marshal
 from nuitka import Options
 from nuitka.__past__ import iterItems, long, unicode  # pylint: disable=W0622
+from nuitka.codegen import Emission
 from nuitka.Constants import (
     constant_builtin_types,
     getConstantWeight,
@@ -46,7 +47,6 @@ from .BlobCodes import StreamData
 from .Emission import SourceCodeCollector
 from .Indentation import indented
 from .Pickling import getStreamedConstant
-from nuitka.codegen import Emission
 
 
 def generateConstantReferenceCode(to_name, expression, emit, context):
@@ -367,7 +367,8 @@ def __addConstantInitCode(context, emit, check, constant_type, constant_value,
             # MININT when used. We work around that warning here.
             emit(
                 """\
-%s = PyLong_FromLong( %sl ); // To be corrected in next line.
+%s = PyLong_FromLong( %sl ); // To be corrected with -1 in-place next lines.
+CHECK_OBJECT( const_int_pos_1 );
 %s = PyNumber_InPlaceSubtract( %s, const_int_pos_1 );""" % (
                     constant_identifier,
                     min_signed_long,
@@ -741,10 +742,10 @@ def getConstantsInitCode(context):
 
     check = SourceCodeCollector()
 
-    # Sort items by length and name, so we are determistic and pretty.
+    # Sort items by length and name, so we are deterministic and pretty.
     sorted_constants = sorted(
         iterItems(context.getConstants()),
-        key = lambda k: (len(k), k )
+        key = lambda k: (len(k[0]), k[0])
     )
 
     for constant_identifier, constant_value in sorted_constants:
@@ -764,10 +765,10 @@ def getConstantsInitCode(context):
 def getConstantsDeclCode(context):
     statements = []
 
-    # Sort items by length and name, so we are determistic and pretty.
+    # Sort items by length and name, so we are deterministic and pretty.
     sorted_constants = sorted(
         iterItems(context.getConstants()),
-        key = lambda k: (len(k), k )
+        key = lambda k: (len(k[0]), k[0])
     )
 
     for constant_identifier, constant_value in sorted_constants:
@@ -913,11 +914,11 @@ constant_counts = {}
 def getConstantInitCodes(module_context):
     decls = []
     inits = Emission.SourceCodeCollector()
-    check = Emission.SourceCodeCollector()
+    checks = Emission.SourceCodeCollector()
 
     sorted_constants = sorted(
         module_context.getConstants(),
-        key = lambda k: (len(k), k)
+        key = lambda k: (len(k[0]), k[0])
     )
 
     global_context = module_context.global_context
@@ -933,7 +934,7 @@ def getConstantInitCodes(module_context):
 
             _addConstantInitCode(
                 emit                = inits,
-                check               = check,
+                check               = checks,
                 constant_type       = type(constant_value),
                 constant_value      = constant_value,
                 constant_identifier = constant_identifier,
@@ -958,7 +959,7 @@ def getConstantInitCodes(module_context):
                 )
             )
 
-    return decls, inits.codes
+    return decls, inits.codes, checks.codes
 
 
 def allocateNestedConstants(module_context):
