@@ -123,22 +123,17 @@ class VariableTraceBase:
            self.variable.isSharedTechnically():
             return False
 
+        # Merge traces have this overloaded.
+
         return self.isInitTrace() or self.isAssignTrace()
 
-    def mustBeUninit(self):
+    def mustNotHaveValue(self):
         if self.variable.isModuleVariable() or \
            self.variable.isSharedTechnically():
             return False
 
         return self.isUninitTrace()
 
-    def mayBeUninit(self):
-        if self.variable.isModuleVariable() or \
-           self.variable.isSharedTechnically():
-            return True
-
-        return self.isUninitTrace() or self.isUnknownTrace()
-
 
 
 class VariableUninitTrace(VariableTraceBase):
@@ -354,7 +349,7 @@ class VariableMergeTrace(VariableTraceBase):
 
         return True
 
-    def mustBeUninit(self):
+    def mustNotHaveValue(self):
         if self.variable.isModuleVariable() or \
            self.variable.isSharedTechnically():
             return False
@@ -364,14 +359,3 @@ class VariableMergeTrace(VariableTraceBase):
                 return False
 
         return True
-
-    def mayBeUninit(self):
-        if self.variable.isModuleVariable() or \
-           self.variable.isSharedTechnically():
-            return True
-
-        for previous in self.previous:
-            if not previous.isUninitTrace() and not previous.isUnknownTrace():
-                return False
-
-        return True
