@@ -22,7 +22,7 @@ One for each type of call. """
 from nuitka.nodes.AssignNodes import (
     StatementAssignmentSubscript,
     StatementAssignmentVariable,
-    StatementDelVariable
+    StatementReleaseVariable
 )
 from nuitka.nodes.AttributeNodes import ExpressionAttributeLookup
 from nuitka.nodes.BuiltinDictNodes import ExpressionBuiltinDict
@@ -668,37 +668,25 @@ def _makeStarDictArgumentToDictStatement(result, called_variable_ref,
     )
 
     final = (
-        StatementDelVariable(
-            variable_ref = ExpressionTargetTempVariableRef(
-                variable   = tmp_dict_variable,
-                source_ref = source_ref
-            ),
-            tolerant     = True,
-            source_ref   = source_ref,
+        StatementReleaseVariable(
+            variable   = tmp_dict_variable,
+            tolerant   = True,
+            source_ref = source_ref
         ),
-        StatementDelVariable(
-            variable_ref = ExpressionTargetTempVariableRef(
-                variable   = tmp_iter_variable,
-                source_ref = source_ref
-            ),
-            tolerant     = True,
-            source_ref   = source_ref,
+        StatementReleaseVariable(
+            variable   = tmp_iter_variable,
+            tolerant   = True,
+            source_ref = source_ref
         ),
-        StatementDelVariable(
-            variable_ref = ExpressionTargetTempVariableRef(
-                variable   = tmp_keys_variable,
-                source_ref = source_ref
-            ),
-            tolerant     = True,
-            source_ref   = source_ref,
+        StatementReleaseVariable(
+            variable   = tmp_keys_variable,
+            tolerant   = True,
+            source_ref = source_ref
         ),
-        StatementDelVariable(
-            variable_ref = ExpressionTargetTempVariableRef(
-                variable   = tmp_key_variable,
-                source_ref = source_ref
-            ),
-            tolerant     = True,
-            source_ref   = source_ref,
+        StatementReleaseVariable(
+            variable   = tmp_key_variable,
+            tolerant   = True,
+            source_ref = source_ref
         )
     )
 
@@ -777,37 +765,25 @@ def _makeStarDictArgumentMergeToKwStatement(result, called_variable_ref,
     tmp_key_variable = result.allocateTempVariable(temp_scope, "key_xxx")
 
     final = [
-        StatementDelVariable(
-            variable_ref = ExpressionTargetTempVariableRef(
-                variable   = tmp_dict_variable,
-                source_ref = source_ref
-            ),
-            tolerant     = True,
-            source_ref   = source_ref,
+        StatementReleaseVariable(
+            variable   = tmp_dict_variable,
+            tolerant   = True,
+            source_ref = source_ref
         ),
-        StatementDelVariable(
-            variable_ref = ExpressionTargetTempVariableRef(
-                variable   = tmp_iter_variable,
-                source_ref = source_ref
-            ),
-            tolerant     = True,
-            source_ref   = source_ref,
+        StatementReleaseVariable(
+            variable   = tmp_iter_variable,
+            tolerant   = True,
+            source_ref = source_ref,
         ),
-        StatementDelVariable(
-            variable_ref = ExpressionTargetTempVariableRef(
-                variable   = tmp_keys_variable,
-                source_ref = source_ref
-            ),
-            tolerant     = True,
-            source_ref   = source_ref,
+        StatementReleaseVariable(
+            variable   = tmp_keys_variable,
+            tolerant   = True,
+            source_ref = source_ref,
         ),
-        StatementDelVariable(
-            variable_ref = ExpressionTargetTempVariableRef(
-                variable   = tmp_key_variable,
-                source_ref = source_ref
-            ),
-            tolerant     = True,
-            source_ref   = source_ref,
+        StatementReleaseVariable(
+            variable   = tmp_key_variable,
+            tolerant   = True,
+            source_ref = source_ref,
         )
     ]
 
@@ -1015,29 +991,20 @@ def _makeStarDictArgumentMergeToKwStatement(result, called_variable_ref,
     tmp_key_variable = result.allocateTempVariable(temp_scope, "key")
 
     final += [
-        StatementDelVariable(
-            variable_ref = ExpressionTargetTempVariableRef(
-                variable   = tmp_iter_variable,
-                source_ref = source_ref
-            ),
-            tolerant     = True,
-            source_ref   = source_ref,
+        StatementReleaseVariable(
+            variable   = tmp_iter_variable,
+            tolerant   = True,
+            source_ref = source_ref,
         ),
-        StatementDelVariable(
-            variable_ref = ExpressionTargetTempVariableRef(
-                variable   = tmp_item_variable,
-                source_ref = source_ref
-            ),
-            tolerant     = True,
-            source_ref   = source_ref,
+        StatementReleaseVariable(
+            variable   = tmp_item_variable,
+            tolerant   = True,
+            source_ref = source_ref,
         ),
-        StatementDelVariable(
-            variable_ref = ExpressionTargetTempVariableRef(
-                variable   = tmp_key_variable,
-                source_ref = source_ref
-            ),
-            tolerant     = True,
-            source_ref   = source_ref,
+        StatementReleaseVariable(
+            variable   = tmp_key_variable,
+            tolerant   = True,
+            source_ref = source_ref,
         )
     ]
 
@@ -1341,10 +1308,26 @@ def getFunctionCallHelperStarList():
         )
     )
 
-    result.setBody(
-        StatementsSequence(
-            statements = statements,
+    final = (
+        StatementReleaseVariable(
+            variable   = called_variable,
+            tolerant   = True,
             source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = star_arg_list_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        )
+    )
+
+    result.setBody(
+        makeStatementsSequenceFromStatement(
+            makeTryFinallyStatement(
+                tried      = statements,
+                final      = final,
+                source_ref = source_ref
+            )
         )
     )
 
@@ -1441,10 +1424,31 @@ def getFunctionCallHelperKeywordsStarList():
         )
     )
 
-    result.setBody(
-        StatementsSequence(
-            statements = statements,
+    final = (
+        StatementReleaseVariable(
+            variable   = called_variable,
+            tolerant   = True,
             source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = kw_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = star_arg_list_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        )
+    )
+
+    result.setBody(
+        makeStatementsSequenceFromStatement(
+            makeTryFinallyStatement(
+                tried      = statements,
+                final      = final,
+                source_ref = source_ref
+            )
         )
     )
 
@@ -1545,10 +1549,31 @@ def getFunctionCallHelperPosStarList():
         )
     )
 
-    result.setBody(
-        StatementsSequence(
-            statements = statements,
+    final = (
+        StatementReleaseVariable(
+            variable   = called_variable,
+            tolerant   = True,
             source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = args_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = star_arg_list_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        )
+    )
+
+    result.setBody(
+        makeStatementsSequenceFromStatement(
+            makeTryFinallyStatement(
+                tried      = statements,
+                final      = final,
+                source_ref = source_ref
+            )
         )
     )
 
@@ -1658,10 +1683,36 @@ def getFunctionCallHelperPosKeywordsStarList():
         )
     )
 
-    result.setBody(
-        StatementsSequence(
-            statements = statements,
+    final = (
+        StatementReleaseVariable(
+            variable   = called_variable,
+            tolerant   = True,
             source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = args_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = kw_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = star_arg_list_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        )
+    )
+
+    result.setBody(
+        makeStatementsSequenceFromStatement(
+            makeTryFinallyStatement(
+                tried      = statements,
+                final      = final,
+                source_ref = source_ref
+            )
         )
     )
 
@@ -1762,10 +1813,26 @@ def getFunctionCallHelperStarDict():
         )
     )
 
-    result.setBody(
-        StatementsSequence(
-            statements = statements,
+    final = (
+        StatementReleaseVariable(
+            variable   = called_variable,
+            tolerant   = True,
             source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = star_arg_dict_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        )
+    )
+
+    result.setBody(
+        makeStatementsSequenceFromStatement(
+            makeTryFinallyStatement(
+                tried      = statements,
+                final      = final,
+                source_ref = source_ref
+            )
         )
     )
 
@@ -1876,10 +1943,31 @@ def getFunctionCallHelperPosStarDict():
         )
     )
 
-    result.setBody(
-        StatementsSequence(
-            statements = statements,
+    final = (
+        StatementReleaseVariable(
+            variable   = called_variable,
+            tolerant   = True,
             source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = args_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = star_arg_dict_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        )
+    )
+
+    result.setBody(
+        makeStatementsSequenceFromStatement(
+            makeTryFinallyStatement(
+                tried      = statements,
+                final      = final,
+                source_ref = source_ref
+            )
         )
     )
 
@@ -2015,10 +2103,31 @@ def getFunctionCallHelperKeywordsStarDict():
         )
     )
 
-    result.setBody(
-        StatementsSequence(
-            statements = statements,
+    final = (
+        StatementReleaseVariable(
+            variable   = called_variable,
+            tolerant   = True,
             source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = kw_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = star_arg_dict_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        )
+    )
+
+    result.setBody(
+        makeStatementsSequenceFromStatement(
+            makeTryFinallyStatement(
+                tried      = statements,
+                final      = final,
+                source_ref = source_ref
+            )
         )
     )
 
@@ -2164,10 +2273,36 @@ def getFunctionCallHelperPosKeywordsStarDict():
         )
     )
 
-    result.setBody(
-        StatementsSequence(
-            statements = statements,
+    final = (
+        StatementReleaseVariable(
+            variable   = called_variable,
+            tolerant   = True,
             source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = args_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = kw_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = star_arg_dict_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        )
+    )
+
+    result.setBody(
+        makeStatementsSequenceFromStatement(
+            makeTryFinallyStatement(
+                tried      = statements,
+                final      = final,
+                source_ref = source_ref
+            )
         )
     )
 
@@ -2266,10 +2401,31 @@ def getFunctionCallHelperStarListStarDict():
         )
     )
 
-    result.setBody(
-        StatementsSequence(
-            statements = statements,
+    final = (
+        StatementReleaseVariable(
+            variable   = called_variable,
+            tolerant   = True,
             source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = star_arg_list_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = star_arg_dict_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        )
+    )
+
+    result.setBody(
+        makeStatementsSequenceFromStatement(
+            makeTryFinallyStatement(
+                tried      = statements,
+                final      = final,
+                source_ref = source_ref
+            )
         )
     )
 
@@ -2383,10 +2539,36 @@ def getFunctionCallHelperPosStarListStarDict():
         )
     )
 
-    result.setBody(
-        StatementsSequence(
-            statements = statements,
+    final = (
+        StatementReleaseVariable(
+            variable   = called_variable,
+            tolerant   = True,
             source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = args_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = star_arg_list_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = star_arg_dict_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        )
+    )
+
+    result.setBody(
+        makeStatementsSequenceFromStatement(
+            makeTryFinallyStatement(
+                tried      = statements,
+                final      = final,
+                source_ref = source_ref
+            )
         )
     )
 
@@ -2496,10 +2678,36 @@ def getFunctionCallHelperKeywordsStarListStarDict():
         )
     )
 
-    result.setBody(
-        StatementsSequence(
-            statements = statements,
+    final = (
+        StatementReleaseVariable(
+            variable   = called_variable,
+            tolerant   = True,
             source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = kw_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = star_arg_list_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = star_arg_dict_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        )
+    )
+
+    result.setBody(
+        makeStatementsSequenceFromStatement(
+            makeTryFinallyStatement(
+                tried      = statements,
+                final      = final,
+                source_ref = source_ref
+            )
         )
     )
 
@@ -2622,11 +2830,42 @@ def getFunctionCallHelperPosKeywordsStarListStarDict():
         )
     )
 
-    result.setBody(
-        StatementsSequence(
-            statements = statements,
+    final = (
+        StatementReleaseVariable(
+            variable   = called_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = args_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = kw_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = star_arg_list_variable,
+            tolerant   = True,
+            source_ref = source_ref
+        ),
+        StatementReleaseVariable(
+            variable   = star_arg_dict_variable,
+            tolerant   = True,
             source_ref = source_ref
         )
     )
 
+    result.setBody(
+        makeStatementsSequenceFromStatement(
+            makeTryFinallyStatement(
+                tried      = statements,
+                final      = final,
+                source_ref = source_ref
+            )
+        )
+    )
+
     return result
