@@ -29,7 +29,6 @@ sys.path.insert(
 )
 from test_common import (
     executeReferenceChecked,
-    checkReferenceCount,
     my_print,
 )
 
@@ -645,14 +644,170 @@ def simpleFunction80():
 
     del simpleFunction80.__doc__
 
+def simpleFunction81():
+    def f():
+        yield 1
+        j
+
+    j = 1
+    x = list( f() )
+
+def simpleFunction82():
+    def f():
+        yield 1
+        j
+
+    j = 1
+    x = f.__doc__
+
+def simpleFunction83():
+    x = list(range(7))
+    x[2] = 5
+
+    j = 3
+    x += [h*2 for h in range(j)]
+
+def simpleFunction84():
+    x = tuple(range(7))
+
+    j = 3
+    x += tuple([h*2 for h in range(j)])
+
+def simpleFunction84():
+    x = list(range(7))
+    x[2] = 3
+    x *= 2
+
+def simpleFunction85():
+    x = "something"
+    x += ""
+
+def simpleFunction86():
+    x = 7
+    x += 2000
+
+def simpleFunction87():
+    class C:
+        def __iadd__(self, other):
+            return self
+
+    x = C()
+    x += C()
+
+def simpleFunction88():
+    x = [1,2]
+    x += [3,4]
+
+def anyArgs(*args, **kw):
+    pass
+
+def simpleFunction89():
+    some_tuple = (
+        simpleFunction89,
+        simpleFunction89,
+        simpleFunction89,
+    )
+
+    anyArgs(*some_tuple)
+
+def simpleFunction90():
+    some_dict = {
+        "a" : simpleFunction90,
+    }
+
+    anyArgs(**some_dict)
+
+def simpleFunction91():
+    some_tuple = (
+        simpleFunction89,
+    )
+
+    some_dict = {
+        "a" : simpleFunction90,
+    }
+
+    anyArgs(*some_tuple, **some_dict)
+
+def simpleFunction92():
+    some_tuple = (
+        simpleFunction89,
+    )
+
+    some_dict = {
+        "a" : simpleFunction90,
+    }
+
+    anyArgs(some_tuple, *some_tuple, **some_dict)
+
+def simpleFunction93():
+    some_tuple = (
+        simpleFunction89,
+    )
+
+    some_dict = {
+        "a" : simpleFunction90,
+    }
+
+    anyArgs(*some_tuple, b = some_dict, **some_dict)
+
+def simpleFunction94():
+    some_tuple = (
+        simpleFunction89,
+    )
+
+    some_dict = {
+        "a" : simpleFunction90,
+    }
+
+    anyArgs(some_tuple, *some_tuple, b = some_dict, **some_dict)
+
+def simpleFunction95():
+    some_tuple = (
+        simpleFunction89,
+    )
+
+    anyArgs(some_tuple, *some_tuple)
+
+def simpleFunction96():
+    some_dict = {
+        "a" : simpleFunction90,
+    }
+
+    anyArgs(b = some_dict, **some_dict)
+
+def simpleFunction97():
+    some_tuple = (
+        simpleFunction89,
+    )
+
+    anyArgs(*some_tuple, b = some_tuple)
+
+def simpleFunction98():
+    some_dict = {
+        "a" : simpleFunction90,
+    }
+
+    anyArgs(some_dict, **some_dict)
+
+def simpleFunction99():
+    def h(f):
+        def g():
+            return f
+
+        return g
+
+    def f():
+        pass
+
+    h(f)
+
+
+
 # These need stderr to be wrapped.
 tests_stderr = (63,)
 
 # Disabled tests
-tests_skipped = {
-   56 : "Functions with closure to themselves are not yet released.",
-   77 : "Functions with closure to themselves are not yet released.",
-}
+tests_skipped = {}
 
 result = executeReferenceChecked(
     prefix        = "simpleFunction",
